# GRID

"GRID has been developed by the team at Digital Science." It is "a free, openly accessible
database of research institution identifiers which enables users to make sense of their data.
It does so by minimising the work required to link datasets together using a unique and
persistent identifier." GRID is "manually curated, offers geo-tagging and is an unbiased
database of over 90,000 institutes."
-- [GRID website](https://www.grid.ac/).

The Global Research Integer Database (GRID) includes data on institutes including acronyms, 
addresses, aliases, external identifiers, geographical name data, labels, links, 
relationships, types, and whether it is an active institution
. _- source: [GRID](https://www.grid.ac/)_ 
and [data details](https://www.grid.ac/format)

## Latest schema
``` eval_rst
.. csv-table::
   :file: ../schemas/grid_latest.csv
   :width: 100%
   :header-rows: 1
```